#!/bin/sh

# Retrieve the name and the version of the image that was modified in the latest commit
# This script should become obsolete as soon as a proper way of getting the modified files is added to Gitlab CI

# Image name, without registry nor tag
RES=""
for i in $(git log -m -1 --name-only --pretty="format:" --first-parent)
do
  case "$i" in
    *pica*|*meta*)
      RES=$(echo $i | cut -d '/' -f1)
      break
      ;;
  esac
done

if [ "$RES" = "" ]; then
  echo "Error : no folder starting by pica or meta modified in last commit."
  echo "Please check README.md for further understanding."
  exit 1;
fi

echo "export MODIFIED_IMAGE=${RES}" > variables
echo "Using modified folder : $RES"

# Image name with wanted registry and tag, fetched from Docker Compose
RES=$(cat $RES/docker-compose.yml | grep $RES: | cut -d ':' -f2- | cut -d '/' -f2- | tr -d ' ' | head -n 1)
if [ "$RES" = "" ]; then
  echo "Error : no reference to $RES found in docker-compose.yml."
  echo "Please check the repository README : the name of the folder must be the same as name of the image."
  exit 1
fi

echo "export MODIFIED_IMAGE_FULL_TEST=registry.test.picasoft.net/${RES}" >> variables
echo "export MODIFIED_IMAGE_FULL=registry.picasoft.net/${RES}" >> variables
